.. AUTO-GENERATED FILE -- DO NOT EDIT!

Module: :mod:`viewer.widgets`
=============================
.. automodule:: skimage.viewer.widgets

.. currentmodule:: skimage.viewer.widgets
.. autosummary::


   skimage.viewer.widgets.BaseWidget
   skimage.viewer.widgets.Button
   skimage.viewer.widgets.CheckBox
   skimage.viewer.widgets.ComboBox
   skimage.viewer.widgets.OKCancelButtons
   skimage.viewer.widgets.SaveButtons
   skimage.viewer.widgets.Slider
   skimage.viewer.widgets.Text

    skimage.viewer.widgets.core
    skimage.viewer.widgets.history


:class:`BaseWidget`
-------------------


.. autoclass:: BaseWidget
  :members:
  :undoc-members:
  :show-inheritance:

  .. automethod:: __init__

.. include:: skimage.viewer.widgets.BaseWidget.examples


:class:`Button`
---------------


.. autoclass:: Button
  :members:
  :undoc-members:
  :show-inheritance:

  .. automethod:: __init__

.. include:: skimage.viewer.widgets.Button.examples


:class:`CheckBox`
-----------------


.. autoclass:: CheckBox
  :members:
  :undoc-members:
  :show-inheritance:

  .. automethod:: __init__

.. include:: skimage.viewer.widgets.CheckBox.examples


:class:`ComboBox`
-----------------


.. autoclass:: ComboBox
  :members:
  :undoc-members:
  :show-inheritance:

  .. automethod:: __init__

.. include:: skimage.viewer.widgets.ComboBox.examples


:class:`OKCancelButtons`
------------------------


.. autoclass:: OKCancelButtons
  :members:
  :undoc-members:
  :show-inheritance:

  .. automethod:: __init__

.. include:: skimage.viewer.widgets.OKCancelButtons.examples


:class:`SaveButtons`
--------------------


.. autoclass:: SaveButtons
  :members:
  :undoc-members:
  :show-inheritance:

  .. automethod:: __init__

.. include:: skimage.viewer.widgets.SaveButtons.examples


:class:`Slider`
---------------


.. autoclass:: Slider
  :members:
  :undoc-members:
  :show-inheritance:

  .. automethod:: __init__

.. include:: skimage.viewer.widgets.Slider.examples


:class:`Text`
-------------


.. autoclass:: Text
  :members:
  :undoc-members:
  :show-inheritance:

  .. automethod:: __init__

.. include:: skimage.viewer.widgets.Text.examples

